<?php
class GAAConfiguration {
  protected $TVC_Admin_Helper;
  protected $subscriptionId;
  protected $TVCProductSyncHelper;
  protected $plan_id;
  public function __construct() {
    $this->includes();
    $this->TVC_Admin_Helper = new TVC_Admin_Helper();
    $this->TVCProductSyncHelper = new TVCProductSyncHelper();
    $this->subscriptionId = $this->TVC_Admin_Helper->get_subscriptionId(); 
    $this->site_url = "admin.php?page=conversios-google-shopping-feed&tab=";     
    $this->url = $this->TVC_Admin_Helper->get_onboarding_page_url(); 
    $this->plan_id = $this->TVC_Admin_Helper->get_plan_id();    
    $this->html_run();
  }
  public function includes() {
    if (!class_exists('Tatvic_Category_Wrapper')) {
      require_once(__DIR__ . '/class-tvc-product-sync-helper.php');
    }
  }

  public function html_run() {
    $this->TVC_Admin_Helper->add_spinner_html();
    $this->create_form();
  }

  public function create_form() {
    if(isset($_GET['welcome_msg']) && sanitize_textarea_field($_GET['welcome_msg']) == true){
      $class = 'notice notice-success';
      $message = esc_html__("Get your WooCommerce products in front of the millions of shoppers across Google by setting up your Google Merchant Center account from below.","conversios");
      printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), esc_html($message));
      ?>
      <script>
        jQuery(document).ready(function() {
          var msg="<?php echo esc_html($message);?>"
          tvc_helper.tvc_alert("success","Hey!",msg,true);
        });
      </script>
      <?php
    }
    $category_wrapper_obj = new Tatvic_Category_Wrapper();
    $category_wrapper = $category_wrapper_obj->category_table_content('mapping');
    $googleDetail = [];
    $google_detail = $this->TVC_Admin_Helper->get_ee_options_data();
	$ee_additional_data = $this->TVC_Admin_Helper->get_ee_additional_data();
    $product_sync_duration = isset($ee_additional_data['product_sync_duration'])?sanitize_text_field($ee_additional_data['product_sync_duration']):"";
    $pro_snyc_time_limit = (isset($ee_additional_data['pro_snyc_time_limit']) && $ee_additional_data['pro_snyc_time_limit'] > 0) ? sanitize_text_field($ee_additional_data['pro_snyc_time_limit']):"25";
    $product_sync_batch_size = (isset($ee_additional_data['product_sync_batch_size']) && $ee_additional_data['product_sync_batch_size'] > 0) ? sanitize_text_field($ee_additional_data['product_sync_batch_size']):"50";
    if(isset($google_detail['setting'])){
      if ($google_detail['setting']) {
        $googleDetail = $google_detail['setting'];
      }
    }?>
<div class="tab-content">
	<div class="tab-pane show active" id="googleShoppingFeed">
    <div class="tab-card">
      <div class="row">
        <div class="col-md-6 col-lg-8 edit-section">
          <div class="configuration-section" id="config-pt1">
            <?php echo get_google_shopping_tabs_html($this->site_url,(isset($googleDetail->google_merchant_center_id))?$googleDetail->google_merchant_center_id:""); ?>
          </div>
          <div class="mt-3" id="config-pt2">
            <div class="google-account-analytics" id="gaa-config">
              <div class="row mb-3">
              <div class="col-6 col-md-6 col-lg-6">
                <h2 class="ga-title"><?php esc_html_e("Connected Google Merchant center account:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6 col-lg-6 text-right">
                <div class="acc-num">
                  <p class="ga-text"><?php echo ((isset($googleDetail->google_merchant_center_id) && esc_attr($googleDetail->google_merchant_center_id) != '') ? esc_attr($googleDetail->google_merchant_center_id) : '<span>'.esc_html__('Get started','conversios').'</span>'); ?></p>
                  <?php
                    if(isset($googleDetail->google_merchant_center_id) && esc_attr($googleDetail->google_merchant_center_id) != ''){
                      echo '<p class="ga-text text-right"><a href="' . esc_url_raw($this->url) . '" class="text-underline" id="connect_google_merchant_center_account"><img src="'.esc_url_raw( ENHANCAD_PLUGIN_URL.'/admin/images/icon/refresh.svg').'" alt="refresh"/></a></p>';
                    }else{
                      echo '<p class="ga-text text-right"><a href="' . esc_url_raw($this->url) . '" class="text-underline" id="connect_google_merchant_center_account"><img src="'. esc_url_raw(ENHANCAD_PLUGIN_URL.'/admin/images/icon/add.svg').'" alt="connect account"/></a></p>';
                    }?>
                </div>
              </div>              
            </div>
            <div class="row mb-3">
              <div class="col-6 col-md-6 col-lg-6">
                <h2 class="ga-title"><?php esc_html_e("Linked Google Ads Account:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6 col-lg-6 text-right">
                <div class="acc-num">
                  <p class="ga-text"><?php echo (isset($googleDetail->google_ads_id) && esc_attr($googleDetail->google_ads_id) != '' ? esc_attr($googleDetail->google_ads_id) : '<span>'.esc_html__('Get started','conversios').'</span>');?></p>
                  <?php
                  if (isset($googleDetail->google_ads_id) && esc_attr($googleDetail->google_ads_id) != '') {
                    echo '<p class="ga-text text-right"><a href="' . esc_url_raw($this->url) . '" class="text-underline" id="linked_google_ads_account"><img src="'. esc_url_raw(ENHANCAD_PLUGIN_URL.'/admin/images/icon/refresh.svg').'" alt="refresh"/></a></p>';
                  } else {
                    echo '<p class="ga-text text-right"><a href="' .esc_url_raw($this->url) . '" class="text-underline" id="linked_google_ads_account"><img src="'. esc_url_raw(ENHANCAD_PLUGIN_URL.'/admin/images/icon/add.svg').'" alt="connect account"/></a></p>';
                  } ?>
                </div>
              </div>
            </div>
            <?php
            if (isset($googleDetail->google_merchant_center_id) && esc_attr($googleDetail->google_merchant_center_id) != '') {?>
            <div class="row mb-3">
              <div class="col-6 col-md-6">
                <h2 class="ga-title"><?php esc_html_e("Sync Products:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6">
                <button id="tvc_btn_product_sync" type="button" class="btn btn-primary btn-success" data-bs-toggle="modal" data-bs-target="#syncProduct"><?php esc_html_e("Sync New Products","conversios"); ?></button>                        
              </div>
            </div>
            <div class="row mb-3">
              <div class="col-6 col-md-6">
                <h2 class="ga-title"><?php esc_html_e("Smart Shopping Campaigns:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6">
                <a href="admin.php?page=conversios-google-shopping-feed&tab=add_campaign_page" class="btn btn-primary btn-success" id="shopping_campaign"><?php esc_html_e("Create Smart Shopping Campaign","conversios"); ?></a>
              </div>
            </div>
            <?php }else{ ?>
            <div class="row mb-3">
              <div class="col-6 col-md-6">
                <h2 class="ga-title"><?php esc_html_e("Sync Products:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6">
              <a href="<?php echo esc_url_raw($this->url); ?>" class="btn btn-primary btn-success"><?php esc_html_e("Sync New Products","conversios"); ?></a>
              </div>
            </div>
            <div class="row mb-3">
              <div class="col-6 col-md-6">
                <h2 class="ga-title"><?php esc_html_e("Smart Shopping Campaigns:","conversios"); ?></h2>
              </div>
              <div class="col-6 col-md-6">
                <a href="<?php echo esc_url_raw($this->url); ?>" class="btn btn-primary btn-success " id="shopping_campaign"><?php esc_html_e("Create Smart Shopping Campaign","conversios"); ?></a>
              </div>
            </div>
            <?php } ?>
            <?php if($this->plan_id != 1){ ?>
            <form method="post" class="tvc-auto-product-sync-form"> 
              <div class="row mb-3">
                <div class="col-6 col-md-6 col-lg-6">
                  <h2 class="ga-title"><?php esc_html_e("Select time interval for product sync","conversios"); ?>
                  <div class="tvc-tooltip tvc-product-sync-toolip">
                    <span class="tvc-tooltiptext tvc-tooltip-right"><?php esc_html_e("This will periodically sync your products in the google merchant center as it is important to keep your store products updated in the merchant center if you are running shopping ads. By default the products will get sync after every 25 days.","conversios"); ?></span>
                    <img src="<?php echo esc_url_raw(ENHANCAD_PLUGIN_URL."/admin/images/icon/informationI.svg"); ?>" alt=""/>
                  </div>
                  <span class="tvc-pro">: (PRO)</span></h2>
                </div>
                <div class="col-6 col-md-6 col-lg-6 text-right">
                  <input id="pro_snyc_time_limit" name="pro_snyc_time_limit" value="<?php echo esc_attr($pro_snyc_time_limit);?>" class="pro_snyc_time_limit" type="number" min="1" max="28" >
                  <select name="product_sync_duration" class="product_sync_duration">
                      <option value="Day" <?php echo esc_attr($product_sync_duration) == 'Day' ? 'selected' : ''?>>Day</option>
                      <option value="hour" <?php echo esc_attr($product_sync_duration) == 'hour' ? 'selected' : ''?>>Hour</option>
                  </select>
                </div>
              </div>
              <div class="row mb-3">
                <div class="col-6 col-md-6 col-lg-6">
                  <h2 class="ga-title"><?php esc_html_e("Select product sync batch size","conversios"); ?>
                  <div class="tvc-tooltip tvc-product-sync-toolip">
                    <span class="tvc-tooltiptext tvc-tooltip-right"><?php esc_html_e("The product sync will happen based on the batch size you select. By default the batch size is 50 products per batch. This should be set up based on your server configuration in order to manage your site performance.","conversios"); ?></span>
                    <img src="<?php echo esc_url_raw(ENHANCAD_PLUGIN_URL."/admin/images/icon/informationI.svg"); ?>" alt=""/>
                  </div>
                  <span class="tvc-pro">: (PRO)</span></h2>
                </div>
                <div class="col-6 col-md-6 col-lg-6 text-right">
                    <select name="product_sync_batch_size" class="product_sync_batch_size">
                      
                      <option value="10" <?php echo esc_attr($product_sync_batch_size) == '10' ? 'selected' : ''?> >10</option>
                      <option value="25" <?php echo esc_attr($product_sync_batch_size) == '25' ? 'selected' : ''?>>25</option>
                      <option value="50" <?php echo esc_attr($product_sync_batch_size) == '50' ? 'selected' : ''?>>50</option>
                      <option value="100" <?php echo esc_attr($product_sync_batch_size) == '100' ? 'selected' : ''?>>100</option>
                    
                    </select>
                </div>
              </div>
              <div class="auto_product_sync_save_button mb-3">
                <div class="col-12 col-md-12 col-lg-12">
                  <button type="submit" id="auto_product_sync_save" class="auto_product_sync_save btn btn-primary btn-success" name="auto_product_sync_setting_save"><?php esc_html_e("Save","conversios"); ?></button>
                </div>
              </div>
            </form>
            <?php }else{ ?>
               <div class="row">
                  <div class="col-6 col-md-6 col-lg-6">
                    <h2 class="ga-title"><?php esc_html_e("Select time interval for product sync:","conversios"); ?><span class="tvc-pro"> (PRO)</span></h2>
                  </div>
                  <div class="col-6 col-md-6 col-lg-6 mt-2">
                    <img src="<?php echo esc_url_raw(ENHANCAD_PLUGIN_URL.'/admin/images/lock-orange.png'); ?>">
                  </div>
               </div>
               <div class="row ">
                  <div class="col-6 col-md-6 col-lg-6">
                      <h2 class="ga-title"><?php esc_html_e("Select product sync batch size:","conversios"); ?><span class="tvc-pro"> (PRO)</span></h2>
                  </div>
                  <div class="col-6 col-md-6 col-lg-6 mt-2">
                    <img src="<?php echo esc_url_raw(ENHANCAD_PLUGIN_URL.'/admin/images/lock-orange.png'); ?>" >
                  </div>
               </div>
           <?php } ?>
            </div>
          </div>
        </div>
        <div class="col-md-6 col-lg-4">
          <?php echo get_tvc_help_html(); ?>
          <div class="tvc-youtube-video">
            <span>Video tutorial:</span>
            <a href="https://www.youtube.com/watch?v=FAV4mybKogg" target="_blank">Walkthrough about Onboarding</a>
            <a href="https://www.youtube.com/watch?v=4pb-oPWHb-8" target="_blank">Walkthrough about Product Sync</a>
            <a href="https://www.youtube.com/watch?v=_C9cemX6jCM" target="_blank">Walkthrough about Smart Shopping Campaign</a>
          </div> 
        </div>
      </div>
    </div>
	</div>
</div>
<?php 
// add product sync popup
echo $this->TVCProductSyncHelper->tvc_product_sync_popup_html();
?>
<?php  
$is_need_to_domain_claim = false;
if(isset($googleDetail->google_merchant_center_id) && esc_attr($googleDetail->google_merchant_center_id) && esc_attr($this->subscriptionId) != "" && isset($googleDetail->is_domain_claim) && esc_attr($googleDetail->is_domain_claim) == '0'){
  $is_need_to_domain_claim = true;
}?>
<script type="text/javascript">
  jQuery(document).ready(function() {

    jQuery(document).on("click", "#shopping_campaign", function(event){
      var el = $(this).text();
      var slug = el.replace(/\s+/g, '_').toLowerCase();
      user_tracking_data('click', 'null','gaa_config_page',slug);
    });    

    jQuery(document).on("click", "#connect_google_merchant_center_account", function(event){
      var el = $(this).attr("id");
      user_tracking_data('click', 'null','gaa_config_page',el);
    });    

    jQuery(document).on("click", "#linked_google_ads_account", function(event){
      var el = $(this).attr("id");
      user_tracking_data('click', 'null','gaa_config_page',el);
    });
       
    jQuery(document).on("click", "#tvc_btn_product_sync", function(event){
      var el = $(this).text();
      var slug = el.replace(/\s+/g, '_').toLowerCase();
      user_tracking_data('click', 'null','gaa_config_page',slug);
      var is_need_to_domain_claim = "<?php echo esc_attr($is_need_to_domain_claim); ?>";
      if(is_need_to_domain_claim == 1 || is_need_to_domain_claim == true){
        event.preventDefault();
        jQuery.post(tvc_ajax_url,{
          action: "tvc_call_domain_claim"
        },function( response ){
          
        });
      }
    }); 
  });
</script>
<script type="text/javascript">
      jQuery(".auto_product_sync_save").click(function(e){
        e.preventDefault();
        let pro_snyc_time_limit = jQuery(".pro_snyc_time_limit").val();
        let product_sync_duration = jQuery(".product_sync_duration").val();
        let product_sync_batch_size = jQuery(".product_sync_batch_size").val();
        var data = {
              action: "auto_product_sync_setting",
              product_sync_duration:product_sync_duration,
              pro_snyc_time_limit:pro_snyc_time_limit,
              product_sync_batch_size:product_sync_batch_size
            };

            jQuery.ajax({
              type: "POST",
              dataType: "json",
              url: tvc_ajax_url,
              data: data,
            beforeSend: function(){
              tvc_helper.loaderSection(true);
            },
            success: function(response){
              if (response.error === false) {          
                tvc_helper.tvc_alert("success","",response.message);
                
              }else{
                tvc_helper.tvc_alert("error","",response.message);
              }
              setTimeout(function(){ 
                tvc_helper.loaderSection(false);
              }, 2000);
            }
        });
      });
</script>
<script type="text/javascript">
    var selectedopt =jQuery('.product_sync_duration').val();
    jQuery('#pro_snyc_time_limit').on('blur', function(e){
      e.preventDefault();
      var val = Number(jQuery(this).val()); 
      if(selectedopt== "hour"){
        if (val > 23 ) {
          jQuery(this).val(23);
        } else if (val < 12) {
           jQuery(this).val(12);
        }
      }else{
        if (val > 28 ) {
          jQuery(this).val(28);
        } else if (val < 1) {
           jQuery(this).val(1);
        }
      }
    });
                  

  jQuery('.product_sync_duration').change(function(){
    var val = Number(jQuery("#pro_snyc_time_limit").val());
    selectedopt=  jQuery(this).val();
    if(selectedopt== "hour"){
      if (val > 23 ) {
        //alert("hour");
        jQuery("#pro_snyc_time_limit").val(23);
      } else if (val < 12) {
         jQuery("#pro_snyc_time_limit").val(12);
      }
    }else{
      if (val > 28 ) {
        //alert("day");
        jQuery("#pro_snyc_time_limit").val(28);
      } else if (val < 1) {
         jQuery("#pro_snyc_time_limit").val(1);
      }
    }
  });
</script>
  <?php 
  } //create_form
} ?>